
(function() { 

/**
* Patterns for detecting the current state. Mainly uses the title tag
*
**/
var REGEX_PATTERNS = {
    LOGIN_PAGE          : /.title.PAPI - Login<.title./i,
    LOGIN_ERROR         : /.title.PAPI - Login Fehler<.title./i,
    LOGGED_IN_STATE     : /.*META HTTP-EQUIV="refresh" .*;URL=\/pls\/papi\/papiadmin.setLoginTime\?in_crimmo=(\w*)\&in_userid=(\d*)"/i, //"
    MAIN_PAGE_STATE     : /.title.PAPI - .*bersicht/i,
    PENDING_MARKS_STATE : /.title.Exammarks - Noten.*bersicht aktuelles Semester/i,
    ALL_MARKS_STATE     : /.title id="document:title".virtuohm - Noten.*bersicht<.title./i,
    INVALID_SESSION     : /Ung.*ltige Session/i,
};

/**
* Class that validates the current request state by comparing it's content with
* Regular Expression Patterns. Needed because VirtuOhm always returns 200, no matter 
* whether a request worked or not. 
**/
window.ResponseValidator = function(html) {
//    html = html.replace(/(\r|\n|\t)/gi,"");
    var testMatch = function(name) {
        return REGEX_PATTERNS[name].test(html) ;
    }
    
    this.isError = function() {
        return testMatch("LOGIN_ERROR") || testMatch("INVALID_SESSION");
    }

    this.isLoginPage = function() {
        return testMatch("LOGIN_PAGE");
    }
    
    this.isLoggedInState = function() {
        return testMatch("LOGGED_IN_STATE");
    }
    
    this.isPendingMarksOverview = function() {
        return testMatch("PENDING_MARKS_STATE");
    }    
    
    this.isMainState = function() {
        return testMatch("MAIN_PAGE_STATE");
    }
    
    this.isOverallMarksOverview = function() {
        return testMatch("ALL_MARKS_STATE");
    }
    
    this.getCurrentState = function() {

        if(testMatch("LOGIN_ERROR"))
            return "login_error";
        if(testMatch("INVALID_SESSION"))
            return "session_timeout";
        if(this.isLoginPage())
            return "login_page";
        if(this.isLoggedInState())
            return "login_success";
        if(this.isMainState())
            return "main_page";
        if(this.isPendingMarksOverview())
            return "pending_marks";
        if(this.isOverallMarksOverview())
            return "overall_marks";
    }
    /**
    * Returns an object with in_crimmo and user_id or null if no parameters are set
    **/
    this.getCredentialParameters = function() {
        if(!this.isLoggedInState())
            return null;
        var result = REGEX_PATTERNS.LOGGED_IN_STATE.exec(html);
        return {
            in_crimmo: result[1],
            in_userid: result[2]
        }
    }
}



})();